=====
Usage
=====

------------
Installation
------------

| **python_object_getter** is available on PyPI hence you can use `pip` to install it.

It is recommended to perform the installation in an isolated `python virtual environment` (env).
You can create and activate an `env` using any tool of your preference (ie `virtualenv`, `venv`, `pyenv`).

Assuming you have 'activated' a `python virtual environment`:

.. code-block:: shell

  python -m pip install python-object-getter


---------------
Simple Use Case
---------------

| Common Use Case for the python_object_getter is to TODO

TODO
